pub enum Error {
    IoError(Error),
    FormatError(&'static str),
    Unsupported(&'static str),
}
An error that prevents successful decoding of the FLAC stream.

Variants

IoError(Error)

Not a decoding error, but a problem with the underlying IO.

FormatError(&'static str)

An ill-formed FLAC stream was encountered.

Unsupported(&'static str)

A currently unsupported feature of the FLAC format was encountered.

Claxon reads the FLAC format as it was with FLAC 1.3.1. Values in the specification that are marked as reserved will cause a FormatError; Unsupported is used for features that are in the specification, but which are not implemented by Claxon.